@@ -18,4 +18,7 @@
 """
 Package "service.snmp"
 """
-from delphixpy.v1_4_2.web.service.snmp.snmp import *
+API_VERSION = "1.11.5"
+
+from delphixpy.v1_11_5.web.service.snmp import v2
+from delphixpy.v1_11_5.web.service.snmp import v3
