@@ -126,6 +126,11 @@ from delphixpy.web.objects.BaseSupportBundleParameters import BaseSupportBundleP
 from delphixpy.web.objects.BatchContainerDeleteParameters import BatchContainerDeleteParameters
 from delphixpy.web.objects.BatchContainerRefreshParameters import BatchContainerRefreshParameters
 from delphixpy.web.objects.BatchSnapshotDeleteParameters import BatchSnapshotDeleteParameters
+from delphixpy.web.objects.BlobObjectStoreAccessKey import BlobObjectStoreAccessKey
+from delphixpy.web.objects.BlobObjectStoreAccessManagedIdentities import BlobObjectStoreAccessManagedIdentities
+from delphixpy.web.objects.BlobObjectStoreAccess import BlobObjectStoreAccess
+from delphixpy.web.objects.BlobObjectStoreTest import BlobObjectStoreTest
+from delphixpy.web.objects.BlobObjectStore import BlobObjectStore
 from delphixpy.web.objects.CaCertificate import CaCertificate
 from delphixpy.web.objects.CallResult import CallResult
 from delphixpy.web.objects.AggregateCapacityData import AggregateCapacityData
@@ -241,6 +246,7 @@ from delphixpy.web.objects.HostCreateParameters import HostCreateParameters
 from delphixpy.web.objects.HostEnvironmentCreateParameters import HostEnvironmentCreateParameters
 from delphixpy.web.objects.HostEnvironment import HostEnvironment
 from delphixpy.web.objects.HostMachine import HostMachine
+from delphixpy.web.objects.HostNfsChecksParameters import HostNfsChecksParameters
 from delphixpy.web.objects.HostOS import HostOS
 from delphixpy.web.objects.HostPrivilegeElevationProfileScript import HostPrivilegeElevationProfileScript
 from delphixpy.web.objects.HostPrivilegeElevationProfile import HostPrivilegeElevationProfile
@@ -357,6 +363,7 @@ from delphixpy.web.objects.MSSqlFailoverClusterDriveLetter import MSSqlFailoverC
 from delphixpy.web.objects.MSSqlFailoverClusterInstance import MSSqlFailoverClusterInstance
 from delphixpy.web.objects.MSSqlFailoverClusterListener import MSSqlFailoverClusterListener
 from delphixpy.web.objects.MSSqlFailoverClusterRepository import MSSqlFailoverClusterRepository
+from delphixpy.web.objects.MSSqlFileMappingParameters import MSSqlFileMappingParameters
 from delphixpy.web.objects.MSSqlInstance import MSSqlInstance
 from delphixpy.web.objects.MSSqlLinkData import MSSqlLinkData
 from delphixpy.web.objects.MSSqlLinkedSourceUpgradeParameters import MSSqlLinkedSourceUpgradeParameters
@@ -379,6 +386,7 @@ from delphixpy.web.objects.MSSqlStagingPushSyncStrategy import MSSqlStagingPushS
 from delphixpy.web.objects.MSSqlStagingSource import MSSqlStagingSource
 from delphixpy.web.objects.MSSqlSyncParameters import MSSqlSyncParameters
 from delphixpy.web.objects.MSSqlSyncStrategy import MSSqlSyncStrategy
+from delphixpy.web.objects.MSSqlTimeflowFilesystemLayout import MSSqlTimeflowFilesystemLayout
 from delphixpy.web.objects.MSSqlTimeflowPoint import MSSqlTimeflowPoint
 from delphixpy.web.objects.MSSqlTimeflow import MSSqlTimeflow
 from delphixpy.web.objects.MSSqlUser import MSSqlUser
@@ -442,6 +450,9 @@ from delphixpy.web.objects.OAuth2Config import OAuth2Config
 from delphixpy.web.objects.OAuth2FailedLoginRecord import OAuth2FailedLoginRecord
 from delphixpy.web.objects.OAuth2SuccessfulLoginRecord import OAuth2SuccessfulLoginRecord
 from delphixpy.web.objects.ObjectNotification import ObjectNotification
+from delphixpy.web.objects.ObjectStoreCacheHitsReport import ObjectStoreCacheHitsReport
+from delphixpy.web.objects.ObjectStoreTestResult import ObjectStoreTestResult
+from delphixpy.web.objects.ObjectStoreTest import ObjectStoreTest
 from delphixpy.web.objects.ObjectStore import ObjectStore
 from delphixpy.web.objects.OKResult import OKResult
 from delphixpy.web.objects.OperationTemplate import OperationTemplate
@@ -532,6 +543,7 @@ from delphixpy.web.objects.OracleStagingSource import OracleStagingSource
 from delphixpy.web.objects.OracleStartParameters import OracleStartParameters
 from delphixpy.web.objects.OracleStopParameters import OracleStopParameters
 from delphixpy.web.objects.OracleSyncFromExternalParameters import OracleSyncFromExternalParameters
+from delphixpy.web.objects.OracleSyncFromStagingParameters import OracleSyncFromStagingParameters
 from delphixpy.web.objects.OracleSyncParameters import OracleSyncParameters
 from delphixpy.web.objects.OracleSyncStrategy import OracleSyncStrategy
 from delphixpy.web.objects.OracleSysauxDatafileSpecification import OracleSysauxDatafileSpecification
@@ -549,6 +561,10 @@ from delphixpy.web.objects.OracleVirtualSource import OracleVirtualSource
 from delphixpy.web.objects.OsAdminStatus import OsAdminStatus
 from delphixpy.web.objects.PasswordCredential import PasswordCredential
 from delphixpy.web.objects.PasswordPolicy import PasswordPolicy
+from delphixpy.web.objects.PasswordResetConfig import PasswordResetConfig
+from delphixpy.web.objects.PasswordResetRequestParameters import PasswordResetRequestParameters
+from delphixpy.web.objects.PasswordResetValidationParameters import PasswordResetValidationParameters
+from delphixpy.web.objects.PasswordResetValidationResult import PasswordResetValidationResult
 from delphixpy.web.objects.PasswordVaultTestParameters import PasswordVaultTestParameters
 from delphixpy.web.objects.PasswordVault import PasswordVault
 from delphixpy.web.objects.PemCertificateChain import PemCertificateChain
@@ -636,7 +652,6 @@ from delphixpy.web.objects.RunPowerShellOnSourceOperation import RunPowerShellOn
 from delphixpy.web.objects.S3ObjectStoreAccessInstanceProfile import S3ObjectStoreAccessInstanceProfile
 from delphixpy.web.objects.S3ObjectStoreAccessKey import S3ObjectStoreAccessKey
 from delphixpy.web.objects.S3ObjectStoreAccess import S3ObjectStoreAccess
-from delphixpy.web.objects.S3ObjectStoreTestResult import S3ObjectStoreTestResult
 from delphixpy.web.objects.S3ObjectStoreTest import S3ObjectStoreTest
 from delphixpy.web.objects.S3ObjectStore import S3ObjectStore
 from delphixpy.web.objects.SchedulePolicy import SchedulePolicy
